@@ -43,7 +43,7 @@ where
                     input_list,
                     flat_scan,
                 } => match input_list.next() {
-                    ListState::Some(first, next) => FlatScanState::OutputList {
+                    ListState::Some(ListSome { first, next }) => FlatScanState::OutputList {
                         output_list: flat_scan.map_item(first),
                         input_list: next,
                     },
@@ -55,14 +55,14 @@ where
                     output_list,
                     input_list,
                 } => match output_list.next() {
-                    ListState::Some(first, output_list) => {
-                        return ListState::Some(
+                    ListState::Some(ListSome { first, next }) => {
+                        return ListState::Some(ListSome {
                             first,
-                            FlatScanState::OutputList {
-                                output_list,
+                            next: FlatScanState::OutputList {
+                                output_list: next,
                                 input_list,
                             },
-                        )
+                        })
                     }
                     ListState::End(flat_scan) => FlatScanState::Begin {
                         input_list,
@@ -71,9 +71,10 @@ where
                 },
                 FlatScanState::EndList(end_list) => {
                     return match end_list.next() {
-                        ListState::Some(first, next) => {
-                            ListState::Some(first, FlatScanState::EndList(next))
-                        }
+                        ListState::Some(ListSome { first, next }) => ListState::Some(ListSome {
+                            first,
+                            next: FlatScanState::EndList(next),
+                        }),
                         ListState::End(end) => ListState::End(end),
                     }
                 }
