@@ -9,7 +9,7 @@ impl<I: Iterator> ListFn for &mut I {
     fn next(self) -> ListState<Self> {
         match self.next() {
             Option::None => ListState::End(self),
-            Option::Some(first) => ListState::Some(first, self),
+            Option::Some(first) => ListState::Some(ListSome { first, next: self }),
         }
     }
 }
@@ -27,7 +27,7 @@ impl<S: ListFn<End = S>> Iterator for ListIterator<S> {
         let mut result = None;
         take(&mut self.0, |list| match list.next() {
             ListState::End(end) => end,
-            ListState::Some(first, next) => {
+            ListState::Some(ListSome { first, next }) => {
                 result = Some(first);
                 next
             }
@@ -59,7 +59,7 @@ impl<L: ListFn> Iterator for ListIteratorWrap<L> {
         take(self, |wrap| match wrap {
             ListIteratorWrap::List(list) => match list.next() {
                 ListState::End(end) => ListIteratorWrap::End(end),
-                ListState::Some(first, next) => {
+                ListState::Some(ListSome { first, next }) => {
                     result = Some(first);
                     ListIteratorWrap::List(next)
                 }
