@@ -9,14 +9,13 @@ mod fold;
 mod iter;
 mod list;
 mod map;
+mod map_result;
 mod option;
 mod option_list;
 mod result;
 mod scan;
 mod take;
-mod map_result;
 
-pub use map_result::*;
 pub use collect::*;
 pub use empty::*;
 pub use filter::*;
@@ -28,6 +27,7 @@ pub use fold::*;
 pub use iter::*;
 pub use list::*;
 pub use map::*;
+pub use map_result::*;
 pub use option::*;
 pub use option_list::*;
 pub use result::*;
@@ -36,6 +36,8 @@ pub use take::*;
 
 #[cfg(test)]
 mod tests {
+    use crate::ListSome;
+
     use super::*;
 
     struct Ref<'a>(&'a mut u32);
@@ -52,7 +54,7 @@ mod tests {
             let first = *self.0;
             if first < 10 {
                 *self.0 += 1;
-                ListState::Some(first, self)
+                ListState::Some(ListSome { first, next: self })
             } else {
                 ListState::End(self)
             }
@@ -72,7 +74,10 @@ mod tests {
         fn next(self) -> ListState<Self> {
             let first = self.0;
             if first < 10 {
-                ListState::Some(first, Self(first + 1))
+                ListState::Some(ListSome {
+                    first,
+                    next: Self(first + 1),
+                })
             } else {
                 ListState::End(self)
             }
