@@ -1,7 +1,8 @@
+pub struct ListSome<F: ListFn> { pub first: F::Item, pub next: F }
+
 /// A list.
 pub enum ListState<F: ListFn> {
-    /// The list has one item and a function to get a next sub list.
-    Some(F::Item, F),
+    Some(ListSome<F>),
     /// The end of the list.
     End(F::End),
 }
