@@ -26,13 +26,13 @@ where
     type End = Id<E::Output>;
     fn next(self) -> ListState<Self> {
         match self.input.next() {
-            ListState::Some(input, next) => ListState::Some(
-                input,
-                MapResultList {
+            ListState::Some(ListSome { first, next }) => ListState::Some(ListSome {
+                first,
+                next: MapResultList {
                     input: next,
                     map: self.map,
                 },
-            ),
+            }),
             ListState::End(end) => ListState::End(Id::new(self.map.map(end.result()))),
         }
     }
@@ -43,14 +43,11 @@ where
     Self: ListFn,
     Self::End: ResultFn,
 {
-    fn with_result<E: MapResultFn<Input = <Self::End as ResultFn>::Result>>(
+    fn map_result<E: MapResultFn<Input = <Self::End as ResultFn>::Result>>(
         self,
         map: E,
     ) -> MapResultList<Self, E> {
-        MapResultList {
-            input: self,
-            map,
-        }
+        MapResultList { input: self, map }
     }
 }
 
