@@ -6,7 +6,10 @@ impl<T> ListFn for Option<T> {
     type End = Self;
     fn next(self) -> ListState<Self> {
         match self {
-            Option::Some(first) => ListState::Some(first, Option::None),
+            Option::Some(first) => ListState::Some(ListSome {
+                first,
+                next: Option::None,
+            }),
             Option::None => ListState::End(Option::None),
         }
     }
