@@ -1,7 +1,7 @@
 use super::*;
 
 pub enum OptionList<I, E> {
-    Some { item: I, end: E },
+    Some { first: I, end: E },
     End(E),
 }
 
@@ -10,7 +10,10 @@ impl<I, E> ListFn for OptionList<I, E> {
     type End = E;
     fn next(self) -> ListState<Self> {
         match self {
-            OptionList::Some { item, end } => ListState::Some(item, OptionList::End(end)),
+            OptionList::Some { first, end } => ListState::Some(ListSome {
+                first,
+                next: OptionList::End(end),
+            }),
             OptionList::End(end) => ListState::End(end),
         }
     }
